# ihu
> Evolve any unitary using solve_ivp


The package will allow you to evolve a unitary, give the
Hamiltonian. We assume closed system dynamics.
So, no lindbladians allowed !!!
One needs to give 
- unitary at time zero, 
- Hamiltonian as a function which depends on time.
- evolution time

From the unitary at time zero we will determine the
shape of the Unitary.
We hope that the hamiltonian that you provide will
be of same shape as that of the unitary

## Install

`pip install ihu`

## How to use

Fill me in please! Don't forget code examples:

```python
1+1
```




    2


